Getting Started
===============

Requirements
-------------

Django Lanthanum requires Django 2 and Postgres in order to implement a JSON Field.

To install, run the following: `pip install django-lanthanum`

